@@ -95,26 +95,18 @@ class PulseBuildMonitor(object):
     """
     pass
 
-  onBuildComplete = on_build_complete
-  onBuildLogAvailable = on_build_complete
-
   def on_test_complete(self, builddata):
     """Called whenever a test log becomes available on the FTP site.  See
        README.txt for explanation of builddata.
     """
     pass
 
-  onTestLogAvailable = on_test_complete
-  onTestComplete = on_test_complete
-
   def on_pulse_message(self, data):
     """Called for every pulse message that we receive; 'data' is the
        unprocessed payload from pulse.
     """
     pass
 
-  onPulseMessage = on_pulse_message
-
   def pulse_message_received(self, data, message):
     """Called whenever our pulse consumer receives a message.
     """
@@ -128,6 +120,8 @@ class PulseBuildMonitor(object):
 
     try:
       self.on_pulse_message(data)
+      if hasattr(self, 'onPulseMessage'):
+          self.onPulseMessage(data)
 
       if key.startswith('unittest') or key.startswith('talos'):
         if self.unittests or self.talos:
@@ -158,6 +152,8 @@ class PulseBuildMonitor(object):
             return
 
           self.on_test_complete(data['payload'])
+          if hasattr(self, 'onTestComplete'):
+              self.onTestComplete(data['payload'])
 
       elif key.startswith('build'):
         if self.builds:
@@ -197,6 +193,8 @@ class PulseBuildMonitor(object):
               raise Exception('buildtags must be a list of strings or a list of lists')
 
           self.on_build_complete(data['payload'])
+          if hasattr(self, 'onBuildComplete'):
+              self.onBuildComplete(data['payload'])
 
       else:
         raise BadPulseMessageError(key)
